==> ulyxex.1.5.1.0.with-tinyMce.zip: pages/core/admin_controllers.php <==
<?php
/* Ulyxex version 1.5.1.0 *****************/
/* add more admin actions and menu items in config file
element 0 = title of action
element 1 = script
element 2 = you can add two type of item in menu admin : "action" to pass through admin.php or "link" to pass outside admin.php, null if you don't want it in menu
element 3 = user level access */
$adminController["articles"] 			= array("articles","pages/admin_articles.php","action",4);
$adminController["add_article"] 		= array("add article","pages/admin_article_add.php",null,4);
$adminController["modify_article"] 		= array("modify article","pages/admin_article_modify.php",null,4);
$adminController["list_files"] 			= array("list files","pages/admin_files_dir.php",null,4);

$adminController["pages"]				= array("pages","pages/admin_pages.php","action",2);
$adminController["add_page"] 			= array("add page","pages/admin_page_add.php",null,2);
$adminController["modify_page"] 		= array("modify page","pages/admin_page_modify.php",null,2);

// $adminController["multiples_uploads"]	= array("uploads","pages/admin_files_uploads.php","action",3);
$adminController["files"]				= array("files","pages/admin_files.php","action",3);
$adminController["ftp_files"]			= array("ftp","pages/admin_ftp_files.php","action",2);

$adminController["users"] 				= array("users","pages/admin_users.php","action",1);
$adminController["add_user"] 			= array("site","pages/admin_user_add.php","",1);
$adminController["modify_user"] 		= array("site","pages/admin_user_modify.php",null,1);
$adminController["my_user_profile"] 	= array("my profile","admin.php?action=modify_user&amp;user=".$_SESSION['userid'],"link",4);

$adminController["admin_home"] 			= array("site","pages/admin_site.php","action",1);

$adminController["login"]				= array("login","login.php","link",4);
$adminController["logout"]				= array("logout","logout.php","link",4);
$adminController["help"]				= array("help","http://ulyxex.logz.org/index.php?k=page&amp;v=3","link",4);

$adminController["phpinfo"]				= array("phpinfo","pages/admin_phpinfo.php",null,1);
/****************************************/
?>

==> ulyxex.1.5.1.7.with-tinyMce.zip: pages/core/admin_controllers.php <==
<?php
/* Ulyxex version 1.5.1.7 *****************/
/* add more admin actions and menu items in config file
element 0 = title of action
element 1 = script
element 2 = you can add two type of item in menu admin : "action" to pass through admin.php or "link" to pass outside admin.php, null if you don't want it in menu
element 3 = user level access */
$adminController["articles"] 			= array("articles","pages/admin_articles.php","action",4);
$adminController["add_article"] 		= array("add article","pages/admin_article_add.php",null,4);
$adminController["modify_article"] 		= array("modify article","pages/admin_article_modify.php",null,4);
$adminController["list_files"] 			= array("list files","pages/admin_files_dir.php",null,4);

$adminController["pages"]				= array("pages","pages/admin_pages.php","action",2);
$adminController["add_page"] 			= array("add page","pages/admin_page_add.php",null,2);
$adminController["modify_page"] 		= array("modify page","pages/admin_page_modify.php",null,2);

// $adminController["multiples_uploads"]	= array("uploads","pages/admin_files_uploads.php","action",3);
$adminController["files"]				= array("files","pages/admin_files.php","action",3);
$adminController["ftp_files"]			= array("ftp","pages/admin_ftp_files.php","action",2);

$adminController["users"] 				= array("users","pages/admin_users.php","action",1);
$adminController["add_user"] 			= array("site","pages/admin_user_add.php","",1);
$adminController["modify_user"] 		= array("site","pages/admin_user_modify.php",null,1);
$adminController["my_user_profile"] 	= array("my-profile","admin.php?action=modify_user&amp;user=".$_SESSION['userid'],"link",4);

$adminController["admin_home"] 			= array("site","pages/admin_site.php","action",1);

$adminController["login"]				= array("login","login.php","link",4);
$adminController["logout"]				= array("logout","logout.php","link",4);
$adminController["help"]				= array("help","http://ulyxex.logz.org/index.php?k=page&amp;v=3","link",4);

$adminController["phpinfo"]				= array("phpinfo","pages/admin_phpinfo.php",null,1);
/****************************************/
?>
